@@ -1,5 +1,5 @@
 package Person;
-use lib qw(. t ../lib);
+
 use strict;
 use vars qw(@ISA @AUTO_ATTRIBUTES @OTHER_ATTRIBUTES %SYNONYMS %AUTODB);
 use Class::AutoClass;
@@ -10,9 +10,9 @@ use DBConnector;
 @OTHER_ATTRIBUTES=qw();
 %SYNONYMS=();
 %AUTODB=(-collection=>__PACKAGE__,
-	   -keys=>qq(name string, sex string, friends list(string)),
+	   -keys=>qq(name string, sex string, friends list(mixed)),
 	  );
+
 Class::AutoClass::declare(__PACKAGE__);
 
-
 1;
