@@ -1,9 +1,11 @@
 package TestAutoDB_2;
-# same as TestAutoDB_3, but with connection params
+
 use lib qw(. t ../lib);
 use strict;
 use vars qw(@ISA @AUTO_ATTRIBUTES @OTHER_ATTRIBUTES %SYNONYMS %AUTODB);
 use Class::AutoClass;
+use DBConnector;
+
 @ISA=qw(Class::AutoClass);
 
   @AUTO_ATTRIBUTES=qw(this that other);
